@@ -19,6 +19,7 @@ if ( grep /\P{ASCII}/ => @ARGV ) {
 
 use Carp;
 use Pg::Explain::Node;
+use Pg::Explain::JIT;
 
 =head1 NAME
 
@@ -26,11 +27,11 @@ Pg::Explain::FromText - Parser for text based explains
 
 =head1 VERSION
 
-Version 1.04
+Version 1.05
 
 =cut
 
-our $VERSION = '1.04';
+our $VERSION = '1.05';
 
 =head1 SYNOPSIS
 
@@ -83,7 +84,7 @@ sub split_into_lines {
         if ( $l =~ m{ \A Trigger \s+ }xms ) {
             push @out, $l;
         }
-        elsif ( $l =~ m{ \A (?: Total \s+ runtime | Planning \s+ time | Execution \s+ time | Time | Filter | Output ): }xmsi ) {
+        elsif ( $l =~ m{ \A (?: Total \s+ runtime | Planning \s+ time | Execution \s+ time | Time | Filter | Output | JIT ): }xmsi ) {
             push @out, $l;
         }
         elsif ( $l =~ m{\A\S} ) {
@@ -115,6 +116,10 @@ sub parse_source {
     my $self   = shift;
     my $source = shift;
 
+    # Store jit text info, and flag whether we're in JIT parsing phase
+    my $jit    = undef;
+    my $in_jit = undef;
+
     my $top_node         = undef;
     my %element_at_depth = ();      # element is hashref, contains 2 keys: node (Pg::Explain::Node) and subelement-type, which can be: subnode, initplan or subplan.
 
@@ -172,6 +177,8 @@ sub parse_source {
             }
             my $element = { 'node' => $new_node, 'subelement-type' => 'subnode', };
 
+            $in_jit = undef;
+
             my $prefix = $+{ 'prefix' };
             $prefix =~ s/->.*//;
             my $prefix_length = length $prefix;
@@ -213,6 +220,8 @@ sub parse_source {
         elsif ( $line =~ m{ \A (\s*) ((?:Sub|Init)Plan) \s* (?: \d+ \s* )? \s* (?: \( returns .* \) \s* )? \z }xms ) {
             my ( $prefix, $type ) = ( $1, $2 );
 
+            $in_jit = undef;
+
             my @remove_elements = grep { $_ >= length $prefix } keys %element_at_depth;
             delete @element_at_depth{ @remove_elements } unless 0 == scalar @remove_elements;
 
@@ -228,6 +237,8 @@ sub parse_source {
         elsif ( $line =~ m{ \A (\s*) CTE \s+ (\S+) \s* \z }xms ) {
             my ( $prefix, $cte_name ) = ( $1, $2 );
 
+            $in_jit = undef;
+
             my @remove_elements = grep { $_ >= length $prefix } keys %element_at_depth;
             delete @element_at_depth{ @remove_elements } unless 0 == scalar @remove_elements;
 
@@ -243,15 +254,24 @@ sub parse_source {
         }
         elsif ( $line =~ m{ \A \s* (Planning|Execution) \s+ time: \s+ (\d+\.\d+) \s+ ms \s* \z }xmsi ) {
             my ( $type, $time ) = ( $1, $2 );
+
+            $in_jit = undef;
+
             $self->explain->planning_time( $time )  if 'planning' eq lc( $type );
             $self->explain->execution_time( $time ) if 'execution' eq lc( $type );
         }
         elsif ( $line =~ m{ \A \s* Total \s+ runtime: \s+ (\d+\.\d+) \s+ ms \s* \z }xmsi ) {
             my ( $time ) = ( $1 );
+
+            $in_jit = undef;
+
             $self->explain->total_runtime( $time );
         }
         elsif ( $line =~ m{ \A \s* Trigger \s+ (.*) : \s+ time=(\d+\.\d+) \s+ calls=(\d+) \s* \z }xmsi ) {
             my ( $name, $time, $calls ) = ( $1, $2, $3 );
+
+            $in_jit = undef;
+
             $self->explain->add_trigger_time(
                 {
                     'name'  => $name,
@@ -260,8 +280,16 @@ sub parse_source {
                 }
             );
         }
+        elsif ( $line =~ m{ \A (\s*) JIT: \s* \z }xmsi ) {
+            $in_jit = 1;
+            $jit    = [ $line ];
+        }
         elsif ( $line =~ m{ \A (\s*) ( \S .* \S ) \s* \z }xms ) {
             my ( $infoprefix, $info ) = ( $1, $2 );
+            if ( $in_jit ) {
+                push @{ $jit }, $line;
+                next LINE;
+            }
             my $maximal_depth = ( sort { $b <=> $a } grep { $_ < length $infoprefix } keys %element_at_depth )[ 0 ];
             next LINE unless defined $maximal_depth;
             my $previous_element = $element_at_depth{ $maximal_depth };
@@ -272,6 +300,7 @@ sub parse_source {
             }
         }
     }
+    $self->explain->jit( Pg::Explain::JIT->new( 'lines' => $jit ) ) if defined $jit;
     return $top_node;
 }
 
@@ -291,7 +320,7 @@ You can find documentation for this module with the perldoc command.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2008-2015 hubert depesz lubaczewski, all rights reserved.
+Copyright 2008-2021 hubert depesz lubaczewski, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
